# Apollogize
Apollogize is a command line tool which assists the employers who forgot to check-in and check-out in Apollo HR app.

## Installation
It's available on pypi, simply use pip to install Apollogize package.
```bash
pip install apollogize
```

## Contribution
```bash
python -m virtualenv venv
pip install --user virtualenv
source venv/bin/activate
pip install --upgrade pip
pip install -r pip-requirements.txt
```

## License
Licensed under the GPLv3 license.